#!/bin/bash

##Install dependencies

sudo apt-get install ca-certificates -y
sudo apt-get install curl -y
sudo apt-get install gnupg -y
sudo apt-get install lsb-release -y

## Installation Wireshark

sudo add-apt-repository ppa:wireshark-dev/stable -y
sudo apt update -y 
sudo apt install wireshark -y

## Clone OpenAirInterface 5G Core

sudo rm -r ~/oai-cn5g-fed
git clone https://gitlab.eurecom.fr/oai/cn5g/oai-cn5g-fed.git ~/oai-cn5g-fed

## Configuration of the packer forwarding

sudo sysctl net.ipv4.conf.all.forwarding=1
sudo iptables -P FORWARD ACCEPT

## Install docker and docker-compose

sudo rm /etc/apt/sources.list.d/docker.list*
sudo mkdir -p /etc/apt/keyrings -y
curl -fsSL https://download.docker.com/linux/ubuntu/gpg | sudo apt-key add -
sudo add-apt-repository "deb [arch=amd64] https://download.docker.com/linux/ubuntu $(. /etc/os-release; echo "$UBUNTU_CODENAME") stable"
sudo chmod a+r /etc/apt/keyrings/docker.gpg -y
sudo apt-get update -y
sudo apt-get install docker-ce docker-ce-cli containerd.io docker-compose-plugin -y
sudo curl -L https://github.com/docker/compose/releases/download/1.29.2/docker-compose-`uname -s`-`uname -m` -o /usr/local/bin/docker-compose
sudo chmod +x /usr/local/bin/docker-compose

## Pulling the images from Docker Hub
sudo docker pull oaisoftwarealliance/oai-amf:develop
sudo docker pull oaisoftwarealliance/oai-nrf:develop
sudo docker pull oaisoftwarealliance/oai-smf:develop
sudo docker pull oaisoftwarealliance/oai-udr:develop
sudo docker pull oaisoftwarealliance/oai-udm:develop
sudo docker pull oaisoftwarealliance/oai-ausf:develop
sudo docker pull oaisoftwarealliance/oai-spgwu-tiny:develop
sudo docker pull oaisoftwarealliance/trf-gen-cn5g:latest

## Tag Docker Images

sudo docker image tag oaisoftwarealliance/trf-gen-cn5g:latest trf-gen-cn5g:latest
sudo docker image tag oaisoftwarealliance/oai-amf:develop oai-amf:develop
sudo docker image tag oaisoftwarealliance/oai-nrf:develop oai-nrf:develop
sudo docker image tag oaisoftwarealliance/oai-smf:develop oai-smf:develop
sudo docker image tag oaisoftwarealliance/oai-udr:develop oai-udr:develop
sudo docker image tag oaisoftwarealliance/oai-udm:develop oai-udm:develop
sudo docker image tag oaisoftwarealliance/oai-ausf:develop oai-ausf:develop
sudo docker image tag oaisoftwarealliance/oai-spgwu-tiny:develop oai-spgwu-tiny:develop

## OAI CN5G Configuration files

sudo wget -O ~/oai-cn5g-fed/docker-compose/docker-compose-basic-nrf.yaml https://gitlab.eurecom.fr/oai/openairinterface5g/-/raw/develop/doc/tutorial_resources/docker-compose-basic-nrf.yaml?inline=false
sudo wget -O ~/oai-cn5g-fed/docker-compose/database/oai_db.sql https://gitlab.eurecom.fr/oai/openairinterface5g/-/raw/develop/doc/tutorial_resources/oai_db.sql?inline=false
sudo chmod +x ~/oai-cn5g-fed/docker-compose/database/oai_db.sql

## Synchronizing the tutorials

cd ~/oai-cn5g-fed
sudo ./scripts/syncComponents.sh
git submodule deinit --all --force
git submodule init
git submodule update

## Creating the bridge 5GC

sudo docker network create --driver=bridge --subnet=192.168.70.128/26 -o "com.docker.network.bridge.name"="demo-oai" demo-oai-public-net

## Deploy the 5GC

cd ~/oai-cn5g-fed/docker-compose
sudo python3 core-network.py --type start-basic --scenario 1

## Docker post-installation

sudo groupadd docker
sudo usermod -aG docker $USER
newgrp docker
